==> push-2.0.71.3-sources.jar: com/voxeet/push/center/NotificationCenterFactory.java <==
package com.voxeet.push.center;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.util.Log;

import com.voxeet.push.center.invitation.IIncomingInvitationListener;
import com.voxeet.push.center.invitation.InvitationBundle;
import com.voxeet.push.center.management.Constants;
import com.voxeet.push.center.management.EnforcedNotificationMode;
import com.voxeet.push.center.management.NotificationMode;
import com.voxeet.push.center.management.VersionFilter;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

public class NotificationCenterFactory {

    private static final String TAG = NotificationCenterFactory.class.getSimpleName();
    public static NotificationCenterFactory instance = new NotificationCenterFactory();
    private Map<NotificationMode, Holder> invitationProviderForModes = new HashMap<>();

    @NonNull
    private EnforcedNotificationMode enforcedNotificationMode = EnforcedNotificationMode.FULLSCREEN_INCOMING_CALL;

    {
        invitationProviderForModes.put(NotificationMode.NONE, new Holder());
    }

    private NotificationCenterFactory() {

    }

    public NotificationCenterFactory setEnforcedNotificationMode(@NonNull EnforcedNotificationMode enforcedNotificationMode) {
        this.enforcedNotificationMode = enforcedNotificationMode;
        return this;
    }

    public NotificationCenterFactory register(@NonNull NotificationMode notificationMode, @Nullable IIncomingInvitationListener invitationProvider) {
        Holder holder = invitationProviderForModes.get(notificationMode);
        if (holder == null) {
            holder = new Holder();
            invitationProviderForModes.put(notificationMode, holder);
        }
        holder.invitationHolder = invitationProvider;
        return this;
    }

    public NotificationCenterFactory register(@NonNull NotificationMode notificationMode, @NonNull VersionFilter filter) {
        Holder holder = invitationProviderForModes.get(notificationMode);
        if (holder == null) {
            holder = new Holder();
            invitationProviderForModes.put(notificationMode, holder);
        }

        if (!holder.filters.contains(filter)) holder.filters.add(filter);
        return this;
    }

    @Nullable
    public IIncomingInvitationListener getIncomingInvitation(@NonNull String manufacturer, int systemAPIVersion) {
        Log.d(TAG, "getIncomingInvitation: checking for " + manufacturer + " " + systemAPIVersion);
        for (NotificationMode notificationMode : enforcedNotificationMode.getModes()) {
            Holder holder = invitationProviderForModes.get(notificationMode);

            Log.d(TAG, "getIncomingInvitation: notificationMode := " + notificationMode);
            Log.d(TAG, "getIncomingInvitation: holder := " + holder);
            if (null != holder && !holder.mustFilter(manufacturer, systemAPIVersion)) {
                Log.d(TAG, "getIncomingInvitation: holder is valid");
                return holder.invitationHolder;
            }
        }

        return null;
    }

    public void onInvitationReceived(@NonNull Context context,
                                     @NonNull Map<String, String> remoteMessage,
                                     @NonNull String manufacturer,
                                     int systemAPIVersion) {
        IIncomingInvitationListener listener = getIncomingInvitation(manufacturer, systemAPIVersion);
        Log.d(TAG, "onInvitationReceived: listener := " + listener);
        if (null != listener) {
            InvitationBundle invitationBundle = new InvitationBundle(remoteMessage);
            listener.onInvitation(context, invitationBundle);
        }
    }

    @NonNull
    public String onInvitationCanceledReceived(@NonNull Context context,
                                               @NonNull Map<String, String> remoteMessage,
                                               @NonNull String manufacturer,
                                               int systemAPIVersion) {
        String conferenceId = "";
        if (remoteMessage.containsKey(Constants.CONF_ID)) {
            conferenceId = remoteMessage.get(Constants.CONF_ID);
        }
        if (null == conferenceId || TextUtils.isEmpty(conferenceId)) {
            conferenceId = "";
        }

        IIncomingInvitationListener listener = getIncomingInvitation(manufacturer, systemAPIVersion);
        Log.d(TAG, "onInvitationCanceledReceived: listener := " + listener);
        if (null != listener) {
            InvitationBundle invitationBundle = new InvitationBundle(remoteMessage);
            listener.onInvitationCanceled(context, conferenceId);
        }

        return conferenceId;
    }

    private class Holder {
        @Nullable
        IIncomingInvitationListener invitationHolder;

        @NonNull
        public List<VersionFilter> filters = new CopyOnWriteArrayList<>();

        public boolean mustFilter(@NonNull String manufacturer, int systemAPIVersion) {
            for (VersionFilter filter : filters) {
                if (filter.mustFilter(manufacturer, systemAPIVersion)) return true;
            }
            return false;
        }

    }
}

==> push-2.0.71.5-sources.jar: com/voxeet/push/center/NotificationCenterFactory.java <==
package com.voxeet.push.center;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.voxeet.push.center.invitation.IIncomingInvitationListener;
import com.voxeet.push.center.invitation.InvitationBundle;
import com.voxeet.push.center.management.Constants;
import com.voxeet.push.center.management.EnforcedNotificationMode;
import com.voxeet.push.center.management.NotificationMode;
import com.voxeet.push.center.management.VersionFilter;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

public class NotificationCenterFactory {

    private static final String TAG = NotificationCenterFactory.class.getSimpleName();
    public static NotificationCenterFactory instance = new NotificationCenterFactory();
    private Map<NotificationMode, Holder> invitationProviderForModes = new HashMap<>();

    @NonNull
    private EnforcedNotificationMode enforcedNotificationMode = EnforcedNotificationMode.FULLSCREEN_INCOMING_CALL;

    {
        invitationProviderForModes.put(NotificationMode.NONE, new Holder());
    }

    private NotificationCenterFactory() {

    }

    public NotificationCenterFactory setEnforcedNotificationMode(@NonNull EnforcedNotificationMode enforcedNotificationMode) {
        this.enforcedNotificationMode = enforcedNotificationMode;
        return this;
    }

    public NotificationCenterFactory register(@NonNull NotificationMode notificationMode, @Nullable IIncomingInvitationListener invitationProvider) {
        Holder holder = invitationProviderForModes.get(notificationMode);
        if (holder == null) {
            holder = new Holder();
            invitationProviderForModes.put(notificationMode, holder);
        }
        holder.invitationHolder = invitationProvider;
        return this;
    }

    public NotificationCenterFactory register(@NonNull NotificationMode notificationMode, @NonNull VersionFilter filter) {
        Holder holder = invitationProviderForModes.get(notificationMode);
        if (holder == null) {
            holder = new Holder();
            invitationProviderForModes.put(notificationMode, holder);
        }

        if (!holder.filters.contains(filter)) holder.filters.add(filter);
        return this;
    }

    @Nullable
    private IIncomingInvitationListener getIncomingInvitation(@NonNull String manufacturer, int systemAPIVersion) {
        for (NotificationMode notificationMode : enforcedNotificationMode.getModes()) {
            Holder holder = invitationProviderForModes.get(notificationMode);

            if (null != holder && !holder.mustFilter(manufacturer, systemAPIVersion)) {
                return holder.invitationHolder;
            }
        }

        return null;
    }

    public void onInvitationReceived(@NonNull Context context,
                                     @NonNull Map<String, String> remoteMessage,
                                     @NonNull String manufacturer,
                                     int systemAPIVersion) {
        IIncomingInvitationListener listener = getIncomingInvitation(manufacturer, systemAPIVersion);
        if (null != listener) {
            InvitationBundle invitationBundle = new InvitationBundle(remoteMessage);
            listener.onInvitation(context, invitationBundle);
        }
    }

    @NonNull
    public String onInvitationCanceledReceived(@NonNull Context context,
                                               @NonNull Map<String, String> remoteMessage,
                                               @NonNull String manufacturer,
                                               int systemAPIVersion) {
        String conferenceId = "";
        if (remoteMessage.containsKey(Constants.CONF_ID)) {
            conferenceId = remoteMessage.get(Constants.CONF_ID);
        }
        if (null == conferenceId || TextUtils.isEmpty(conferenceId)) {
            conferenceId = "";
        }

        IIncomingInvitationListener listener = getIncomingInvitation(manufacturer, systemAPIVersion);
        if (null != listener) {
            InvitationBundle invitationBundle = new InvitationBundle(remoteMessage);
            listener.onInvitationCanceled(context, conferenceId);
        }

        return conferenceId;
    }

    private class Holder {
        @Nullable
        IIncomingInvitationListener invitationHolder;

        @NonNull
        public List<VersionFilter> filters = new CopyOnWriteArrayList<>();

        public boolean mustFilter(@NonNull String manufacturer, int systemAPIVersion) {
            for (VersionFilter filter : filters) {
                if (filter.mustFilter(manufacturer, systemAPIVersion)) return true;
            }
            return false;
        }

    }
}
